==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/is.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: is.php,v 1.13 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Kerfisupplsingar';

$text['vitals']         = 'Helstu upplsingar';
$text['hostname']       = 'Vlarnafn';
$text['ip']             = 'IP-tala';
$text['kversion']       = 'tgfa kjarna';
$text['dversion']       = 'Nafn dreifingar';
$text['uptime']         = 'Uppitmi';
$text['users']          = 'Notendur';
$text['loadavg']        = 'Meallag';

$text['hardware']       = 'Upplsingar um vlbna';
$text['numcpu']         = 'Fjldi rgjrva';
$text['cpumodel']       = 'Tegund';
$text['cpuspeed']       = 'Hrai';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Str fltiminnis';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI jaartki';
$text['ide']            = 'IDE jaartki';
$text['scsi']           = 'SCSI jaartki';
$text['usb']            = 'USB jaartki';

$text['netusage']       = 'Netnotkun';
$text['device']         = 'Jaartki';
$text['received']       = 'Mtteki';
$text['sent']           = 'Sent';
$text['errors']         = 'Villur/Hent';

$text['memusage']       = 'Minnisnotkun';
$text['phymem']         = 'Vinnsluminni';
$text['swap']           = 'Sndarminni';

$text['fs']             = 'Tengd skrarkerfi';
$text['mount']          = 'Tengipunktur';
$text['partition']      = 'Disksnei';

$text['percent']        = 'Hlutfall af heildarstr';
$text['type']           = 'Tegund';
$text['free']           = 'Laust';
$text['used']           = 'Nota';
$text['size']           = 'Str';
$text['totals']         = 'Samtals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ekkert';

$text['capacity']       = 'Heildarstr'; 

$text['template']       = 'Snimt';
$text['language']       = 'Tunguml';
$text['submit']         = 'Senda';
$text['created']        = 'Bi til af';
$text['locale']         = 'is_IS';
$text['gen_time']       = 'ann %d.%m.%Y kl. %H:%M';

$text['days']           = 'dagar';
$text['hours']          = 'klukkustundir';
$text['minutes']        = 'mntur';
  
$text['temperature']    = 'Hitastig';
$text['voltage']        = 'Volt';
$text['fans']           = 'Viftur';
$text['s_value']        = 'Gildi';
$text['s_min']          = 'Lgst';
$text['s_max']          = 'Hst';
$text['s_div']          = 'Deilir';
$text['hysteresis']     = 'Avrun lkur';
$text['s_limit']        = 'Avrun byrjar';
$text['s_label']        = 'Nafn mlis';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/is.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: is.php,v 1.16 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'Kerfisupplsingar';

$text['vitals']         = 'Helstu upplsingar';
$text['hostname']       = 'Vlarnafn';
$text['ip']             = 'IP-tala';
$text['kversion']       = 'tgfa kjarna';
$text['dversion']       = 'Nafn dreifingar';
$text['uptime']         = 'Uppitmi';
$text['users']          = 'Notendur';
$text['loadavg']        = 'Meallag';

$text['hardware']       = 'Upplsingar um vlbna';
$text['numcpu']         = 'Fjldi rgjrva';
$text['cpumodel']       = 'Tegund';
$text['cpuspeed']       = 'Hrai';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Str fltiminnis';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI jaartki';
$text['ide']            = 'IDE jaartki';
$text['scsi']           = 'SCSI jaartki';
$text['usb']            = 'USB jaartki';

$text['netusage']       = 'Netnotkun';
$text['device']         = 'Jaartki';
$text['received']       = 'Mtteki';
$text['sent']           = 'Sent';
$text['errors']         = 'Villur/Hent';

$text['memusage']       = 'Minnisnotkun';
$text['phymem']         = 'Vinnsluminni';
$text['swap']           = 'Sndarminni';

$text['fs']             = 'Tengd skrarkerfi';
$text['mount']          = 'Tengipunktur';
$text['partition']      = 'Disksnei';

$text['percent']        = 'Hlutfall af heildarstr';
$text['type']           = 'Tegund';
$text['free']           = 'Laust';
$text['used']           = 'Nota';
$text['size']           = 'Str';
$text['totals']         = 'Samtals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ekkert';

$text['capacity']       = 'Heildarstr'; 

$text['template']       = 'Snimt';
$text['language']       = 'Tunguml';
$text['submit']         = 'Senda';
$text['created']        = 'Bi til af';
$text['locale']         = 'is_IS';
$text['gen_time']       = 'ann %d.%m.%Y kl. %H:%M';

$text['days']           = 'dagar';
$text['hours']          = 'klukkustundir';
$text['minutes']        = 'mntur';
  
$text['temperature']    = 'Hitastig';
$text['voltage']        = 'Volt';
$text['fans']           = 'Viftur';
$text['s_value']        = 'Gildi';
$text['s_min']          = 'Lgst';
$text['s_max']          = 'Hst';
$text['s_div']          = 'Deilir';
$text['hysteresis']     = 'Avrun lkur';
$text['s_limit']        = 'Avrun byrjar';
$text['s_label']        = 'Nafn mlis';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
